# -*- coding: utf-8 -*-
# Generated by Django 1.10.6 on 2018-04-03 10:57
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('djangovirtualpos', '0013_vposredsys_enable_preauth_policy'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='vposredsys',
            name='enable_preauth_policy',
        ),
        migrations.AddField(
            model_name='vposredsys',
            name='operative_type',
            field=models.CharField(choices=[('authorization', 'autorizaci\xf3n'), ('pre-authorization', 'pre-autorizaci\xf3n')], default='authorization', max_length=512, verbose_name='Tipo de operativa'),
        ),
    ]
