# -*- coding: utf-8 -*-
# Generated by Django 1.10.6 on 2018-02-09 12:22
from __future__ import unicode_literals

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('djangovirtualpos', '0011_auto_20170404_1424'),
    ]

    operations = [
        migrations.CreateModel(
            name='VPOSBitpay',
            fields=[
                ('parent', models.OneToOneField(db_column='vpos_id', on_delete=django.db.models.deletion.CASCADE, parent_link=True, primary_key=True, related_name='+', serialize=False, to='djangovirtualpos.VirtualPointOfSale')),
                ('testing_api_key', models.CharField(blank=True, max_length=512, null=True, verbose_name='API Key de Bitpay para entorno de test')),
                ('production_api_key', models.CharField(max_length=512, verbose_name='API Key de Bitpay para entorno de producci\xf3n')),
                ('currency', models.CharField(choices=[('EUR', 'Euro'), ('USD', 'Dolares'), ('BTC', 'Bitcoin')], default='EUR', max_length=3, verbose_name='Moneda (EUR, USD, BTC)')),
                ('transaction_speed', models.CharField(choices=[('high', 'Alta'), ('medium', 'Media'), ('low', 'Baja')], default='medium', max_length=10, verbose_name='Velocidad de la operaci\xf3n')),
                ('notification_url', models.URLField(verbose_name='Url notificaciones actualizaci\xf3n estados (https)')),
                ('operation_number_prefix', models.CharField(blank=True, max_length=20, null=True, verbose_name='Prefijo del n\xfamero de operaci\xf3n')),
            ],
            bases=('djangovirtualpos.virtualpointofsale',),
        ),
        migrations.AlterField(
            model_name='virtualpointofsale',
            name='type',
            field=models.CharField(choices=[('ceca', 'TPV Virtual - Confederaci\xf3n Espa\xf1ola de Cajas de Ahorros (CECA)'), ('paypal', 'Paypal'), ('redsys', 'TPV Redsys'), ('santanderelavon', 'TPV Santander Elavon'), ('bitpay', 'TPV Bitpay')], default='', max_length=16, verbose_name='Tipo de TPV'),
        ),
        migrations.AlterField(
            model_name='vpospaymentoperation',
            name='type',
            field=models.CharField(choices=[('ceca', 'TPV Virtual - Confederaci\xf3n Espa\xf1ola de Cajas de Ahorros (CECA)'), ('paypal', 'Paypal'), ('redsys', 'TPV Redsys'), ('santanderelavon', 'TPV Santander Elavon'), ('bitpay', 'TPV Bitpay')], default='', max_length=16, verbose_name='Tipo de TPV'),
        ),
    ]
