# -*- coding: utf-8 -*-
# Generated by Django 1.10.6 on 2017-04-04 14:24
from __future__ import unicode_literals

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('djangovirtualpos', '0010_auto_20170329_1227'),
    ]

    operations = [
        migrations.AlterField(
            model_name='vposrefundoperation',
            name='payment',
            field=models.ForeignKey(on_delete=django.db.models.deletion.PROTECT, related_name='refund_operations', to='djangovirtualpos.VPOSPaymentOperation'),
        ),
    ]
