# -*- coding: utf-8 -*-
# Generated by Django 1.10.6 on 2018-04-03 09:53
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('djangovirtualpos', '0012_auto_20180209_1222'),
    ]

    operations = [
        migrations.AddField(
            model_name='vposredsys',
            name='enable_preauth_policy',
            field=models.BooleanField(default=False, verbose_name='Habilitar pol\xedtica de preautorizaci\xf3n'),
        ),
    ]
